[gnome-software] update dialog: Translator comment for the window subtitle



commit 4f3cb4a17ccc3e295991d0d33a3c3d50edf72e11
Author: Rafal Luzynski <digitalfreak lingonborough com>
Date:   Thu Dec 31 00:12:01 2015 +0100

    update dialog: Translator comment for the window subtitle
    
    The English string was too ambiguous, it was not obvious that
    "%s" is the install date of the update. Thanks for the hints,
    afranke and andre.
    
    https://bugzilla.gnome.org/show_bug.cgi?id=759818
    
    Signed-off-by: Richard Hughes <richard hughsie com>

 src/gs-update-dialog.c |    5 ++++-
 1 files changed, 4 insertions(+), 1 deletions(-)
---
diff --git a/src/gs-update-dialog.c b/src/gs-update-dialog.c
index b2a99cd..ad9e4da 100644
--- a/src/gs-update-dialog.c
+++ b/src/gs-update-dialog.c
@@ -232,7 +232,10 @@ gs_update_dialog_show_installed_updates (GsUpdateDialog *dialog)
                date = g_date_time_new_from_unix_utc (time_updates_installed);
                date_str = g_date_time_format (date, "%x");
 
-               /* TRANSLATORS: this is the subtitle of the installed updates dialog window */
+               /* TRANSLATORS: this is the subtitle of the installed updates dialog window.
+                  %s will be replaced by the date when the updates were installed.
+                  The date format is defined by the locale's preferred date representation
+                  ("%x" in strftime.) */
                subtitle = g_strdup_printf (_("Installed on %s"), date_str);
                header = gtk_dialog_get_header_bar (GTK_DIALOG (dialog));
                gtk_header_bar_set_subtitle (GTK_HEADER_BAR (header), subtitle);


[Date Prev][Date Next]   [Thread Prev][Thread Next]   [Thread Index] [Date Index] [Author Index]